==> moodle_1.4.3.orig.tar.gz: moodle/lang/cs/error.php <==
<?PHP // $Id$ 
      // error.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2004100800)


$string['confirmsesskeybad'] = 'Je mi lto, ale kli vaeho sezen (session) nebylo povoleno vykonat tuto akci. Toto bezpenostn opaten zabrauje nahodilmu nebo zkenmu spoustn dleitch funkc pod vam jmnem. Prosm, ujistte se, e opravdu chcete spustit tuto funkci. ';
$string['coursegroupunknown'] = 'Nebyl uren kurz odpovdajc skupin $a';
$string['erroronline'] = 'Chyba na dku $a';
$string['fieldrequired'] = '\'$a\' je povinn pole';
$string['filenotfound'] = 'Je mi lto, poadovan soubor nebyl nalezen';
$string['groupalready'] = 'Uivatel u je lenem skupiny $a';
$string['groupunknown'] = 'Skupina $a nebyla pidruena k urenmu kurzu';
$string['invalidfieldname'] = '$a nen platn nzev pole';
$string['missingfield'] = 'Chyb pole';
$string['modulerequirementsnotmet'] = 'Modul \"$a->modulename\" ($a->moduleversion) nemohl bt nainstalovn. Vyaduje novj verzi Moodle (pouvte verzi $a->currentmoodle, potebujete $a->requiremoodle).';
$string['notavailable'] = 'Prozatm nen dostupn';
$string['restricteduser'] = 'Je mi lto, ale stvajcmu tu \'$a\' bylo zakzno toto provst.';
$string['sessionipnomatch'] = 'Je mi lto, ale vae IP se v prbhu vaeho pihlen zmnila. Toto bezpenostn opaten zabrauje tonkm vydvat se za pihlenho uivatele. Bnm uivatelm by se tato zprva nemla zobrazit - spojte se s vam sprvcem a podejte jej o pomoc.';
$string['unknowncourse'] = 'Neznm kurz s nzvem \'$a\'';
$string['usernotaddederror'] = 'Uivatel \'$a\' nebyl pidn - neznm chyba';
$string['usernotaddedregistered'] = 'Uivatel \'$a\' nebyl pidn - ji registrovn';
$string['usernotavailable'] = 'Informace o tomto uivateli vm nejsou dostupn.';

?>

==> moodle_1.5.2.orig.tar.gz: moodle/lang/cs/error.php <==
<?PHP // $Id$ 
      // error.php - created with Moodle 1.5 + (2005060201)


$string['adminprimarynoedit'] = 'Primrn sprvce neme bt ostatnmi upravovn';
$string['confirmsesskeybad'] = 'Je mi lto, ale kli vaeho sezen (session) nebylo povoleno vykonat tuto akci. Toto bezpenostn opaten zabrauje nahodilmu nebo zkenmu spoustn dleitch funkc pod vam jmnem. Prosm, ujistte se, e opravdu chcete spustit tuto funkci. ';
$string['coursegroupunknown'] = 'Nebyl uren kurz odpovdajc skupin $a';
$string['erroronline'] = 'Chyba na dku $a';
$string['fieldrequired'] = '\'$a\' je povinn pole';
$string['filenotfound'] = 'Je mi lto, poadovan soubor nebyl nalezen';
$string['groupalready'] = 'Uivatel u je lenem skupiny $a';
$string['groupunknown'] = 'Skupina $a nebyla pidruena k urenmu kurzu';
$string['invalidfieldname'] = '$a nen platn nzev pole';
$string['missingfield'] = 'Chyb pole';
$string['modulerequirementsnotmet'] = 'Modul \"$a->modulename\" ($a->moduleversion) nemohl bt nainstalovn. Vyaduje novj verzi Moodle (pouvte verzi $a->currentmoodle, potebujete $a->requiremoodle).';
$string['notavailable'] = 'Prozatm nen dostupn';
$string['onlyeditown'] = 'Mete upravovat pouze sv vlastn informace';
$string['processingstops'] = 'Zde se zpracovn zastavilo. Zbvajc zznamy byly ignorovny.';
$string['restricteduser'] = 'Je mi lto, ale stvajcmu tu \'$a\' bylo zakzno toto provst.';
$string['sessionerroruser'] = 'Vae pihlen vyprelo. Prosm, pihlate se znovu.';
$string['sessionipnomatch'] = 'Je mi lto, ale vae IP se v prbhu vaeho pihlen zmnila. Toto bezpenostn opaten zabrauje tonkm vydvat se za pihlenho uivatele. Bnm uivatelm by se tato zprva nemla zobrazit - spojte se s vam sprvcem a podejte jej o pomoc.';
$string['unknowncourse'] = 'Neznm kurz s nzvem \'$a\'';
$string['usernotaddederror'] = 'Uivatel \'$a\' nebyl pidn - neznm chyba';
$string['usernotaddedregistered'] = 'Uivatel \'$a\' nebyl pidn - ji registrovn';
$string['usernotavailable'] = 'Informace o tomto uivateli vm nejsou dostupn.';

?>
